@@ -3,7 +3,8 @@ package Ryu::Exception;
 use strict;
 use warnings;
 
-our $VERSION = '1.012'; # VERSION
+our $VERSION = '2.000'; # VERSION
+our $AUTHORITY = 'cpan:TEAM'; # AUTHORITY
 
 =head1 NAME
 
@@ -95,10 +96,6 @@ sub as_future {
     return Future->fail($self->message, $self->type, $self->details);
 }
 
-# Legacy support - will be dropped in 1.0,
-# probably should warn before then anyway.
-*future = *as_future;
-
 =head2 from_future
 
 Extracts failure information from a L<Future> and instantiates accordingly.
