@@ -3,7 +3,8 @@ package Ryu::Node;
 use strict;
 use warnings;
 
-our $VERSION = '1.012'; # VERSION
+our $VERSION = '2.000'; # VERSION
+our $AUTHORITY = 'cpan:TEAM'; # AUTHORITY
 
 =head1 NAME
 
@@ -123,6 +124,8 @@ sub label { shift->{label} }
 
 sub parent { shift->{parent} }
 
+sub new_future { shift->{new_future}->() }
+
 1;
 
 __END__
